@@ -12,7 +12,6 @@ from dataclasses import dataclass, field
 from typing import (
     Any,
     Callable,
-    Coroutine,
     Dict,
     Generic,
     Iterator,
@@ -31,7 +30,13 @@ from typing import (
     runtime_checkable,
 )
 
-from ..utils.async_tools import async_event, create_sub_future, create_sub_task
+from ..utils.async_tools import (
+    HasThreaded,
+    async_event,
+    create_sub_future,
+    create_sub_task,
+    run_coroutine_in_thread,
+)
 from ..utils.dataclasses import as_json, from_dict
 from ..utils.inspect import ensure_coroutine, iter_methods
 from ..utils.logging import LoggingDescriptor
@@ -70,6 +75,8 @@ class JsonRPCErrors:
     SERVER_ERROR_START = -32000
     SERVER_ERROR_END = -32099
 
+    REQUEST_CANCELLED = -32800
+
 
 PROTOCOL_VERSION = "2.0"
 
@@ -469,9 +476,13 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
     def _handle_messages(self, iterator: Iterator[JsonRPCMessage]) -> None:
         def done(f: asyncio.Future[Any]) -> None:
-            ex = f.exception()
-            if ex is not None and not isinstance(ex, asyncio.CancelledError):
-                self._logger.exception(ex, exc_info=ex)
+            if f.done() and not f.cancelled():
+                ex = f.exception()
+
+                if ex is None or isinstance(ex, asyncio.CancelledError):
+                    return
+
+                # self._logger.exception(ex, exc_info=ex)
 
         for m in iterator:
             create_sub_task(self.handle_message(m)).add_done_callback(done)
@@ -479,13 +490,13 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
     @_logger.call
     async def handle_message(self, message: JsonRPCMessage) -> None:
         if isinstance(message, JsonRPCRequest):
-            self.handle_request(message)
+            await self.handle_request(message)
         elif isinstance(message, JsonRPCNotification):
-            self.handle_notification(message)
+            await self.handle_notification(message)
         elif isinstance(message, JsonRPCError):
-            self.handle_error(message)
+            await self.handle_error(message)
         elif isinstance(message, JsonRPCResponse):
-            self.handle_response(message)
+            await self.handle_response(message)
 
     @_logger.call
     def send_response(self, id: Optional[Union[str, int, None]], result: Optional[Any] = None) -> None:
@@ -562,7 +573,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         self.send_message(JsonRPCNotification(method=method, params=params))
 
     @_logger.call(exception=True)
-    def handle_response(self, message: JsonRPCResponse) -> None:
+    async def handle_response(self, message: JsonRPCResponse) -> None:
         if message.id is None:
             error = "Invalid response. Response id is null."
             self._logger.warning(error)
@@ -587,7 +598,12 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                     entry.future.set_result(res)
                 else:
                     if entry.future._loop.is_running():
-                        entry.future._loop.call_soon_threadsafe(entry.future.set_result, res)
+
+                        def s(f: asyncio.Future[Any], r: Any) -> None:
+                            if not f.done():
+                                f.set_result(r)
+
+                        entry.future._loop.call_soon_threadsafe(s, entry.future, res)
                     else:
                         self._logger.warning("Response loop is not running.")
 
@@ -601,7 +617,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                     entry.future._loop.call_soon_threadsafe(entry.future.set_exception, e)
 
     @_logger.call
-    def handle_error(self, message: JsonRPCError) -> None:
+    async def handle_error(self, message: JsonRPCError) -> None:
         raise JsonRPCErrorException(message.error.code, message.error.message, message.error.data)
 
     @staticmethod
@@ -661,7 +677,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
         return args, kw_args
 
     @_logger.call
-    def handle_request(self, message: JsonRPCRequest) -> Optional[asyncio.Task[_T]]:
+    async def handle_request(self, message: JsonRPCRequest) -> None:
         e = self.registry.get_entry(message.method)
 
         if e is None or not callable(e.method):
@@ -674,10 +690,13 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
         params = self._convert_params(e.method, e.param_type, message.params)
 
-        task = create_sub_task(
-            ensure_coroutine(e.method)(*params[0], **params[1]),
-            name=message.method,
-        )
+        if isinstance(e.method, HasThreaded) and cast(HasThreaded, e.method).__threaded__:
+            task = run_coroutine_in_thread(ensure_coroutine(e.method), *params[0], **params[1])
+        else:
+            task = create_sub_task(
+                ensure_coroutine(e.method)(*params[0], **params[1]),
+                name=message.method,
+            )
         with self._received_request_lock:
             self._received_request[message.id] = ReceivedRequestEntry(task, message, e.cancelable)
 
@@ -686,10 +705,11 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                 self.send_response(message.id, t.result())
             except asyncio.CancelledError:
                 self._logger.debug(f"request message {repr(message)} canceled")
+                self.send_error(JsonRPCErrors.REQUEST_CANCELLED, "Request canceled.", id=message.id)
             except (SystemExit, KeyboardInterrupt):
                 raise
-            except JsonRPCErrorException as ex:
-                self.send_error(ex.code, ex.message, id=message.id, data=ex.data)
+            except JsonRPCErrorException as e:
+                self.send_error(e.code, e.message or f"{type(e).__name__}: {e}", id=message.id, data=e.data)
             except BaseException as e:
                 self._logger.exception(e)
                 self.send_error(JsonRPCErrors.INTERNAL_ERROR, f"{type(e).__name__}: {e}", id=message.id)
@@ -699,7 +719,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
 
         task.add_done_callback(done)
 
-        return task
+        await task
 
     @_logger.call
     def cancel_request(self, id: Union[int, str, None]) -> None:
@@ -717,7 +737,7 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
                 entry.future.cancel()
 
     @_logger.call
-    def handle_notification(self, message: JsonRPCNotification) -> None:
+    async def handle_notification(self, message: JsonRPCNotification) -> None:
         e = self.registry.get_entry(message.method)
 
         if e is None or not callable(e.method):
@@ -725,10 +745,16 @@ class JsonRPCProtocol(JsonRPCProtocolBase):
             return
         try:
             params = self._convert_params(e.method, e.param_type, message.params)
-            result = e.method(*params[0], **params[1])
-            if inspect.isawaitable(result):
-                create_sub_task(cast(Coroutine[Any, Any, Any], result))
 
+            if isinstance(e.method, HasThreaded) and cast(HasThreaded, e.method).__threaded__:
+                task = run_coroutine_in_thread(ensure_coroutine(e.method), *params[0], **params[1])
+            else:
+                task = create_sub_task(
+                    ensure_coroutine(e.method)(*params[0], **params[1]),
+                    name=message.method,
+                )
+
+            await task
         except asyncio.CancelledError:
             pass
         except (SystemExit, KeyboardInterrupt):
