@@ -93,4 +93,4 @@ class CodeLensProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities):
         ):
             return
 
-        await self.parent.send_request_async("workspace/codeLens/refresh")
+        return await self.parent.send_request("workspace/codeLens/refresh")
