@@ -3,7 +3,7 @@ from enum import Enum
 from typing import TYPE_CHECKING, Any, Optional, Tuple
 
 from ...common.lsp_types import Position, Range
-from ..utils.ast_utils import Token
+from ..utils.ast_utils import Token, range_from_token
 
 if TYPE_CHECKING:
     from .library_doc import KeywordDoc
@@ -15,7 +15,17 @@ class SourceEntity:
     col_offset: int
     end_line_no: int
     end_col_offset: int
-    source: str
+    source: Optional[str]
+
+    @property
+    def range(self) -> Range:
+        return Range(
+            start=Position(line=self.line_no - 1, character=self.col_offset),
+            end=Position(line=self.end_line_no - 1, character=self.end_col_offset),
+        )
+
+    def __hash__(self) -> int:
+        return hash((self.line_no, self.col_offset, self.end_line_no, self.end_col_offset, self.source))
 
 
 @dataclass
@@ -23,6 +33,7 @@ class Import(SourceEntity):
     name: Optional[str]
     name_token: Optional[Token]
 
+    @property
     def range(self) -> Range:
         return Range(
             start=Position(
@@ -83,9 +94,10 @@ class InvalidVariableError(Exception):
 
 class VariableMatcher:
     def __init__(self, name: str) -> None:
-        from robot.utils.normalizing import normalize
         from robot.variables.search import VariableSearcher
 
+        from ..utils.match import normalize
+
         self.name = name
 
         searcher = VariableSearcher("$@&%", ignore_errors=True)
@@ -96,7 +108,7 @@ class VariableMatcher:
 
         self.base = match.base
 
-        self.normalized_name = str(normalize(self.base, "_"))
+        self.normalized_name = str(normalize(self.base))
 
     def __eq__(self, o: object) -> bool:
         from robot.utils.normalizing import normalize
@@ -108,7 +120,7 @@ class VariableMatcher:
             searcher = VariableSearcher("$@&%", ignore_errors=True)
             match = searcher.search(o)
             base = match.base
-            normalized = str(normalize(base, "_"))
+            normalized = str(normalize(base))
             return self.normalized_name == normalized
         else:
             return False
@@ -154,8 +166,16 @@ class VariableDefinition(SourceEntity):
         return self.__matcher
 
     def __hash__(self) -> int:
-        return hash((type(self), self.name, self.type, self.range, self.source, self.name_token))
+        return hash((type(self), self.name, self.type, self.range, self.source))
 
+    @property
+    def name_range(self) -> Range:
+        if self.name_token is not None:
+            return range_from_token(self.name_token)
+        else:
+            return self.range
+
+    @property
     def range(self) -> Range:
         return Range(
             start=Position(
